==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Toutes les polices</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinois</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospace</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 est une famille de polices, si vous continuez, toutes les polices qu&apos;elle contient seront supprimées </translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 est une famille de polices, si vous continuez, toutes les polices de cette famille seront activées.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 est une famille de polices, si vous continuez, toutes les polices de cette famille seront désactivées.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Désactiver</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished">Appliquer à toutes les familles de polices sélectionnées</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Fichier corrompu</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Même version installée</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Police du système</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Maj+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgAR</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgAV</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Polices</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 police installée</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 polices installées</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Fichier corrompu</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Cette police ne sera plus disponible pour les applications</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ces polices ne seront pas disponibles pour les applications</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Les autres polices système %1 ne peuvent pas être supprimées</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La police &quot;%1&quot; en cours d&apos;utilisation ne peut pas être supprimée</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Les autres polices système %1 et la police &quot;%2&quot; en cours d&apos;utilisation ne peuvent pas être supprimées</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Voulez-vous vraiment supprimer %1 police(s) ?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Suppression des polices, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Vérification des polices</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Aucune police à installer</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuer</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Ne laissez pas vos rêves devenir des rêves</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informations de base</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Style</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nom </translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps nom</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marque déposée</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gestionnaire de polices</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Le gestionnaire des polices aide les utilisateurs à installer et à gérer les polices.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Chargement des polices, veuillez patienter...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>La police a été exportée sur votre bureau</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 polices exportées vers votre bureau</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Impossible d&apos;exporter 1 police. L&apos;espace disque est insuffisant.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Impossible d&apos;exporter %1 polices. L&apos;espace disque est insuffisant.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Ajouter une police</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>désactivé</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Les polices ont été désactivées</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 est en cours d&apos;utilisation, vous ne pouvez donc pas le désactiver</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Vous ne pouvez pas désactiver les polices système et les polices utilisées</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Vous ne pouvez pas désactiver les polices système</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Installer la police</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Vérification en cours...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Fichier corrompu</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installé</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Non installé</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Installer la police</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Aucune police</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Ajouter une police</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Information sur la police de caractères</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Saisir un texte d&apos;aperçu</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.13.orig.tar.xz: deepin-font-manager-5.9.13/translations/deepin-font-manager_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Toutes les polices</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinois</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monospace</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 est une famille de polices, si vous continuez, toutes les polices qu&apos;elle contient seront supprimées </translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 est une famille de polices, si vous continuez, toutes les polices de cette famille seront activées.</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 est une famille de polices, si vous continuez, toutes les polices de cette famille seront désactivées.</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Désactiver</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Appliquer à toutes les familles de polices sélectionnées</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Fichier corrompu</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Même version installée</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Police du système</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Maj+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgAR</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgAV</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 police installée</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 polices installées</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Impossible d&apos;installer les polices %1. L&apos;espace disque est insuffisant.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Cette police ne sera plus disponible pour les applications</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ces polices ne seront pas disponibles pour les applications</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Les autres polices système %1 ne peuvent pas être supprimées</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>La police &quot;%1&quot; en cours d&apos;utilisation ne peut pas être supprimée</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Les autres polices système %1 et la police &quot;%2&quot; en cours d&apos;utilisation ne peuvent pas être supprimées</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Voulez-vous vraiment supprimer %1 police(s) ?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Suppression des polices, veuillez patienter...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Vérification des polices</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Aucune police à installer</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuer</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Info de base</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Style</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nom </translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps nom</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marque déposée</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gestionnaire de polices</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Le gestionnaire des polices aide les utilisateurs à installer et à gérer les polices.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Chargement des polices, veuillez patienter...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>La police a été exportée sur votre bureau</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 polices exportées vers votre bureau</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Impossible d&apos;exporter 1 police. L&apos;espace disque est insuffisant.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Impossible d&apos;exporter %1 polices. L&apos;espace disque est insuffisant.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Ajouter une police</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>désactivé</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Les polices ont été désactivées</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 est en cours d&apos;utilisation, vous ne pouvez donc pas le désactiver</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Vous ne pouvez pas désactiver les polices système et les polices utilisées</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Vous ne pouvez pas désactiver les polices système</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Installer la police</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Vérification en cours...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Fichier corrompu</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Installé</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Non installé</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Installer la police</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Aucune police</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Ajouter une police</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Information sur la police de caractères</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Saisir un texte d&apos;aperçu</translation>
    </message>
</context>
</TS>
